@@ -5,7 +5,7 @@ use warnings;
 
 use Carp;
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 # Preloaded methods go here.
 sub new {
@@ -58,6 +58,11 @@ __END__
 
 WWW::Scraper::ISBN::Driver - Driver class for WWW::Scraper::ISBN module.
 
+=head1 WARNING
+
+This distribution will be deprecated in the near future. The module within is
+to be merged into the main WWW-Scraper-ISBN distribution.
+
 =head1 SYNOPSIS
 
     use WWW::Scraper::ISBN::Driver;
@@ -223,12 +228,12 @@ L<WWW::Scraper::ISBN::Record>
 =head1 AUTHOR
 
   2004-2013 Andy Schamp, E<lt>andy@schamp.netE<gt>
-  2013      Barbie, E<lt>barbie@cpan.orgE<gt>
+  2013-2014 Barbie, E<lt>barbie@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
   Copyright 2004-2013 by Andy Schamp
-  Copyright 2013 by Barbie
+  Copyright 2013-2014 by Barbie
 
   This distribution is free software; you can redistribute it and/or
   modify it under the Artistic Licence v2.
